@@ -3,14 +3,15 @@ package CGI::Wiki::Search::DBIxFTS;
 use strict;
 use DBIx::FullTextSearch;
 use Carp "croak";
+use base 'CGI::Wiki::Search::Base';
 
 use vars qw( @ISA $VERSION );
 
-$VERSION = 0.04;
+$VERSION = 0.05;
 
 =head1 NAME
 
-CGI::Wiki::Search::DBIxFTS - DBIx::FullTextSearch search plugin for CGI::Wiki
+CGI::Wiki::Search::DBIxFTS - DBIx::FullTextSearch search plugin for CGI::Wiki.
 
 =head1 REQUIRES
 
@@ -23,7 +24,9 @@ DBIx::FullTextSearch
   my $search = CGI::Wiki::Search::DBIxFTS->new( dbh => $store->dbh );
   my %wombat_nodes = $search->search_nodes("wombat");
 
-Provides search-related methods for CGI::Wiki
+Provides search-related methods for CGI::Wiki.
+
+See also L<CGI::Wiki::Search::Base>, for methods not documented here.
 
 =cut
 
@@ -42,13 +45,6 @@ alone one that is compatible with DBIx::FullTextSearch.)
 
 =cut
 
-sub new {
-    my ($class, @args) = @_;
-    my $self = {};
-    bless $self, $class;
-    return $self->_init(@args);
-}
-
 sub _init {
     my ($self, %args) = @_;
     croak "Must supply a database handle" unless $args{dbh};
@@ -56,28 +52,8 @@ sub _init {
     return $self;
 }
 
-=item B<search_nodes>
-
-  # Find all the nodes which contain both the word 'expert' and the
-  # phrase 'wombat defenestration'.
-  %results = $search->search_nodes('expert "wombat defenestration"');
-
-  # Find all the nodes which contain at least one of the words
-  # 'buffy', 'pony', and 'pie'.
-  %results = $search->search_nodes('buffy pony pie', 'OR');
-
-Returns a (possibly empty) hash whose keys are the node names and
-whose values are the scores in some kind of relevance-scoring system I
-haven't entirely come up with yet. For OR searches, this could
-initially be the number of terms that appear in the node, perhaps.
-
-Defaults to AND searches (if $and_or is not supplied, or is anything
-other than C<OR> or C<or>).
-
-Searches are case-insensitive.
-
-=cut
-
+# We can't use the base version, since we're doing the analysis
+# differently between searching and indexing
 sub search_nodes {
     my ($self, $termstr, $and_or) = @_;
 
@@ -86,10 +62,6 @@ sub search_nodes {
         $and_or = "AND";
     }
 
-    # Note: Not sure yet whether the term extraction below is going to be
-    # common between backends.  Move it back into CGI::Wiki if it turns
-    # out to be.
-
     # Extract individual search terms - first phrases (between double quotes).
     my @terms = ($termstr =~ m/"([^"]+)"/g);
     $termstr =~ s/"[^"]*"//g;
@@ -108,15 +80,6 @@ sub search_nodes {
     return map { $_ => 1 } @finds;
 }
 
-=item B<index_node>
-
-  $search->index_node($node);
-
-Indexes or reindexes the given node in the FTS indexes in the backend
-storage.
-
-=cut
-
 sub index_node {
     my ($self, $node) = @_;
 
@@ -131,16 +94,6 @@ sub index_node {
     delete $fts_titles->{db_backend}; # ditto
 }
 
-=item B<delete_node>
-
-  $search->delete_node($node);
-
-Removes the given node from the search indexes.  NOTE: It's up to you to
-make sure the node is removed from the backend store.  Croaks on error,
-returns true on success.
-
-=cut
-
 sub delete_node {
     my ($self, $node) = @_;
     my $dbh = $self->{_dbh};
@@ -155,26 +108,14 @@ sub delete_node {
     return 1;
 }
 
-=item B<supports_phrase_searches>
-
-  if ( $search->supports_phrase_searches ) {
-      return $search->search_nodes( '"fox in socks"' );
-  }
-
-Returns true if this search backend supports phrase searching, and
-false otherwise.
-
-=cut
-
-sub supports_phrase_searches {
-    return 1;
-}
+sub supports_phrase_searches { return 1; }
+sub supports_fuzzy_searches  { return 0; }
 
 =back
 
 =head1 SEE ALSO
 
-L<CGI::Wiki>
+L<CGI::Wiki>,  L<CGI::Wiki::Search::Base>.
 
 =cut
 
