@@ -3,7 +3,7 @@ package CGI::Wiki::Setup::MySQL;
 use strict;
 
 use vars qw( $VERSION );
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 use DBI;
 use Carp;
@@ -72,9 +72,16 @@ Set up a MySQL database for use as a CGI::Wiki store.
   use CGI::Wiki::Setup::MySQL;
   CGI::Wiki::Setup::MySQL::setup($dbname, $dbuser, $dbpass, $dbhost);
 
-Takes three mandatory arguments -- the database name, the username and the
-password. The username must be able to create and drop tables in the
-database.
+or
+
+  CGI::Wiki::Setup::Mysql::setup( $dbh );
+
+You can either provide an active database handle C<$dbh> or connection
+parameters.                                                                    
+
+If you provide connection parameters the following arguments are
+mandatory -- the database name, the username and the password. The
+username must be able to create and drop tables in the database.
 
 The $dbhost argument is optional -- omit it if the database is local.
 
@@ -87,14 +94,9 @@ again with a fresh database, run C<cleardb> first.
 =cut
 
 sub setup {
-    my ($dbname, $dbuser, $dbpass, $dbhost) = _get_args(@_);
-
-    my $dsn = "dbi:mysql:$dbname";
-    $dsn .= ";host=$dbhost" if $dbhost;
-    my $dbh = DBI->connect($dsn, $dbuser, $dbpass,
-			   { PrintError => 1, RaiseError => 1,
-			     AutoCommit => 1 } )
-      or croak DBI::errstr;
+    my @args = @_;
+    my $dbh = _get_dbh( @args );
+    my $disconnect_required = _disconnect_required( @args );
 
     # Check whether tables exist, set them up if not.
     my $sth = $dbh->prepare("SHOW TABLES") or croak $dbh->errstr;
@@ -115,20 +117,27 @@ sub setup {
         }
     }
 
-    # Clean up.
-    $dbh->disconnect;
+    # Clean up if we made our own dbh.
+    $dbh->disconnect if $disconnect_required;
 }
 
 =item B<cleardb>
 
   use CGI::Wiki::Setup::MySQL;
 
-  # Clear out the old database completely, then set up tables afresh.
+  # Clear out all CGI::Wiki tables from the database.
   CGI::Wiki::Setup::MySQL::cleardb($dbname, $dbuser, $dbpass, $dbhost);
-  CGI::Wiki::Setup::MySQL::setup($dbname, $dbuser, $dbpass, $dbhost);
 
-Takes three mandatory arguments -- the database name, the username and the
-password. The username must be able to drop tables in the database.
+or
+
+  CGI::Wiki::Setup::Mysql::cleardb( $dbh );
+
+You can either provide an active database handle C<$dbh> or connection
+parameters.                                                                    
+
+If you provide connection parameters the following arguments are
+mandatory -- the database name, the username and the password. The
+username must be able to drop tables in the database.
 
 The $dbhost argument is optional -- omit if the database is local.
 
@@ -143,31 +152,73 @@ which search backend you're using.
 =cut
 
 sub cleardb {
-    my ($dbname, $dbuser, $dbpass, $dbhost) = _get_args(@_);
-
-    my $dsn = "dbi:mysql:$dbname";
-    $dsn .= ";host=$dbhost" if $dbhost;
-    my $dbh = DBI->connect($dsn, $dbuser, $dbpass,
-			   { PrintError => 1, RaiseError => 1,
-			     AutoCommit => 1 } )
-      or croak DBI::errstr;
+    my @args = @_;
+    my $dbh = _get_dbh( @args );
+    my $disconnect_required = _disconnect_required( @args );
 
     print "Dropping tables... ";
     $dbh->do("DROP TABLE IF EXISTS " . join( ",", keys %create_sql ) )
       or croak $dbh->errstr;
     print "done\n";
 
-    # Clean up.
-    $dbh->disconnect;
+    # Clean up if we made our own dbh.
+    $dbh->disconnect if $disconnect_required;
 }
 
-sub _get_args {
-    if ( ref $_[0] ) {
-        my %hash = %{$_[0]};
-        return @hash{ qw( dbname dbuser dbpass dbhost ) };
-    } else {
-        return @_;
+sub _get_dbh {
+    # Database handle passed in.
+    if ( ref $_[0] and ref $_[0] eq 'DBI::db' ) {
+        return $_[0];
     }
+
+    # Args passed as hashref.
+    if ( ref $_[0] and ref $_[0] eq 'HASH' ) {
+        my %args = %{$_[0]};
+        if ( $args{dbh} ) {
+            return $args{dbh};
+	} else {
+            return _make_dbh( %args );
+        }
+    }
+
+    # Args passed as list of connection details.
+    return _make_dbh(
+                      dbname => $_[0],
+                      dbuser => $_[1],
+                      dbpass => $_[2],
+                      dbhost => $_[3],
+                    );
+}
+
+sub _disconnect_required {
+    # Database handle passed in.
+    if ( ref $_[0] and ref $_[0] eq 'DBI::db' ) {
+        return 0;
+    }
+
+    # Args passed as hashref.
+    if ( ref $_[0] and ref $_[0] eq 'HASH' ) {
+        my %args = %{$_[0]};
+        if ( $args{dbh} ) {
+            return 0;
+	} else {
+            return 1;
+        }
+    }
+
+    # Args passed as list of connection details.
+    return 1;
+}
+
+sub _make_dbh {
+    my %args = @_;
+    my $dsn = "dbi:mysql:$args{dbname}";
+    $dsn .= ";host=$args{dbhost}" if $args{dbhost};
+    my $dbh = DBI->connect($dsn, $args{dbuser}, $args{dbpass},
+			   { PrintError => 1, RaiseError => 1,
+			     AutoCommit => 1 } )
+      or croak DBI::errstr;
+    return $dbh;
 }
 
 =back
@@ -187,6 +238,10 @@ you can pass them as
     }
   )
 
+or indeed as
+
+  ( { dbh => $dbh } )
+
 Note that's a hashref, not a hash.
 
 =head1 AUTHOR
@@ -195,7 +250,7 @@ Kake Pugh (kake@earth.li).
 
 =head1 COPYRIGHT
 
-     Copyright (C) 2002-2003 Kake Pugh.  All Rights Reserved.
+     Copyright (C) 2002-2004 Kake Pugh.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
